@@ -2,7 +2,7 @@ use std::fmt::{Debug, Display};
 use std::{env, io, net, result, string::FromUtf8Error};
 use thiserror::Error;
 
-#[derive(Debug)]
+#[derive(Debug, Error)]
 pub struct Error(Box<ErrorImpl>);
 
 impl Display for Error {
@@ -72,6 +72,10 @@ pub enum ErrorImpl {
     },
     #[error("invalid api request, message: {message:?}")]
     ApiRequest { message: String },
+    #[error("build error, operation: {operation:?}, message: {message:?}")]
+    Build { operation: String, message: String },
+    #[error("repository error, operation: {operation:?}, message: {message:?}")]
+    Repository { operation: String, message: String },
 }
 
 impl From<std::io::Error> for Error {
@@ -211,6 +215,14 @@ pub fn invalid_catalog_name(reason: String, message: String) -> Error {
     Error(Box::new(ErrorImpl::CatalogName { reason, message }))
 }
 
+pub fn build_error(operation: String, message: String) -> Error {
+    Error(Box::new(ErrorImpl::Build { operation, message }))
+}
+
+pub fn repository_error(operation: String, message: String) -> Error {
+    Error(Box::new(ErrorImpl::Repository { operation, message }))
+}
+
 // rpc status
 pub fn rpc_internal_error(error: Error) -> tonic::Status {
     tonic::Status::internal(format!("{:#?}", error))
