@@ -40,7 +40,7 @@ pub mod node_client {
     impl<T> NodeClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -184,7 +184,7 @@ pub mod node_server {
     impl<T, B> tonic::codegen::Service<http::Request<B>> for NodeServer<T>
     where
         T: Node,
-        B: Body + Send + Sync + 'static,
+        B: Body + Send + 'static,
         B::Error: Into<StdError> + Send + 'static,
     {
         type Response = http::Response<tonic::body::BoxBody>;
