@@ -13,6 +13,7 @@ mod namespace;
 mod project;
 mod register;
 mod resource;
+mod schedule;
 mod service;
 mod time;
 mod utils;
@@ -30,6 +31,7 @@ pub use namespace::*;
 pub use project::*;
 pub use register::*;
 pub use resource::*;
+pub use schedule::*;
 pub use service::*;
 pub use time::*;
 pub use utils::*;
