@@ -1,3 +1,4 @@
+use crate::{Resource, ResourceType};
 use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 
@@ -18,3 +19,9 @@ impl Default for Namespace {
         Self::new()
     }
 }
+
+impl Resource for Namespace {
+    fn ty() -> ResourceType {
+        ResourceType::Namespace
+    }
+}
